Skip to main contentModule raw
Source - Bucket
- A reference to a hash table bucket containing a
T. - InsertSlot
- A reference to an empty bucket into which an can be inserted.
- RawDrain
- Iterator which consumes elements without freeing the table storage.
- RawIntoIter
- Iterator which consumes a table and returns elements.
- RawIter
- Iterator which returns a raw pointer to every full bucket in the table.
- RawIterHash
- Iterator over occupied buckets that could match a given hash.
- RawTable
- A raw hash table with an unsafe API.